---
 Changelog                          |    2 +-
 avconv.c                           |    2 +-
 doc/avserver.texi                  |    2 +-
 doc/soc.txt                        |    2 +-
 ffmpeg.c                           |    2 +-
 libavcodec/arm/dsputil_init_neon.c |    2 +-
 libavcodec/arm/dsputil_neon.S      |    2 +-
 libavcodec/arm/fft_neon.S          |    2 +-
 libavcodec/arm/fmtconvert_neon.S   |    2 +-
 libavcodec/arm/int_neon.S          |    2 +-
 libavcodec/arm/mdct_neon.S         |    2 +-
 libavcodec/arm/rdft_neon.S         |    2 +-
 libavcodec/arm/vp8dsp_neon.S       |    2 +-
 libavcodec/avcodec.h               |    2 +-
 libavcodec/bfi.c                   |   10 +++++-----
 libavcodec/bink.c                  |   14 +++++++-------
 libavcodec/bitstream.c             |    2 +-
 libavcodec/bmp.c                   |    2 +-
 libavcodec/cavs.c                  |    4 ++--
 libavcodec/cavs.h                  |    4 ++--
 libavcodec/cinepak.c               |    4 ++--
 libavcodec/cook.c                  |    2 +-
 libavcodec/eatgv.c                 |    4 ++--
 libavcodec/error_resilience.c      |    2 +-
 libavcodec/g722.c                  |    2 +-
 libavcodec/h264.c                  |    8 ++++----
 libavcodec/h264.h                  |    4 ++--
 libavcodec/h264_ps.c               |    6 +++---
 libavcodec/ivi_common.h            |    2 +-
 libavcodec/mpegvideo.h             |    2 +-
 libavcodec/proresdec.c             |    2 +-
 libavcodec/rv34.c                  |    4 ++--
 libavcodec/rv40.c                  |   12 ++++++------
 libavcodec/vaapi_h264.c            |    2 +-
 libavcodec/vaapi_mpeg4.c           |    2 +-
 libavcodec/wmaprodec.c             |    2 +-
 libavcodec/x86/rv40dsp.c           |    4 ++--
 libavcodec/x86/vc1dsp_yasm.asm     |    2 +-
 libavdevice/jack_audio.c           |    2 +-
 libavdevice/oss_audio.c            |    2 +-
 libavdevice/v4l.c                  |    2 +-
 libavformat/avformat.h             |    5 +++--
 libavformat/id3v2.c                |    2 +-
 libavformat/iv8.c                  |    2 +-
 libavformat/mms.h                  |    2 +-
 libavformat/mov.c                  |    8 ++++----
 libavformat/mxfenc.c               |    2 +-
 libavformat/timefilter.h           |    2 +-
 libavformat/utils.c                |    4 ++--
 libavutil/avr32/intreadwrite.h     |    2 +-
 libavutil/eval.h                   |    2 +-
 libpostproc/postprocess.c          |    2 +-
 libpostproc/postprocess_internal.h |    2 +-
 tools/patcheck                     |    2 +-
 54 files changed, 87 insertions(+), 86 deletions(-)

diff --git a/Changelog b/Changelog
index 48ce306..892b1c8 100644
--- a/Changelog
+++ b/Changelog
@@ -585,7 +585,7 @@ version 0.4.5:
 - fixed VIDIOCSYNC interrupt
 - added Intel H.263 decoding support ('I263' AVI fourCC)
 - added Real Video 1.0 decoding (needs further testing)
-- simplified image formats again. Added PGM format (=grey
+- simplified image formats again. Added PGM format (=gray
   pgm). Renamed old PGM to PGMYUV.
 - fixed msmpeg4 slice issues (tell me if you still find problems)
 - fixed OpenDivX bugs with newer versions (added VOL header decoding)
diff --git a/avconv.c b/avconv.c
index c418b7c..7d8398a 100644
--- a/avconv.c
+++ b/avconv.c
@@ -3474,7 +3474,7 @@ static void opt_output_file(void *optctx, const char 
*filename)
     }
 
     if (!(oc->oformat->flags & AVFMT_NOFILE)) {
-        /* test if it already exists to avoid loosing precious files */
+        /* test if it already exists to avoid losing precious files */
         if (!file_overwrite &&
             (strchr(filename, ':') == NULL ||
              filename[1] == ':' ||
diff --git a/doc/avserver.texi b/doc/avserver.texi
index 7ac4a13..d2e0580 100644
--- a/doc/avserver.texi
+++ b/doc/avserver.texi
@@ -146,7 +146,7 @@ that only captures in stereo and also requires that one 
channel be flipped.
 If you are one of these people, then export 'AUDIO_FLIP_LEFT=1' before
 starting ffmpeg.
 
-@subsection The audio and video loose sync after a while.
+@subsection The audio and video lose sync after a while.
 
 Yes, they do.
 
diff --git a/doc/soc.txt b/doc/soc.txt
index e45bd6c..89728b5 100644
--- a/doc/soc.txt
+++ b/doc/soc.txt
@@ -18,7 +18,7 @@ essential that changes to their codebase are publicly 
visible, clean and
 easy reviewable that again leads us to:
 * use of a revision control system like git
 * separation of cosmetic from non-cosmetic changes (this is almost entirely
-  ignored by mentors and students in soc 2006 which might lead to a suprise
+  ignored by mentors and students in soc 2006 which might lead to a surprise
   when the code will be reviewed at the end before a possible inclusion in
   Libav, individual changes were generally not reviewable due to cosmetics).
 * frequent commits, so that comments can be provided early
diff --git a/ffmpeg.c b/ffmpeg.c
index 86b73b2..769ce2e 100644
--- a/ffmpeg.c
+++ b/ffmpeg.c
@@ -3796,7 +3796,7 @@ static void opt_output_file(void *optctx, const char 
*filename)
     }
 
     if (!(oc->oformat->flags & AVFMT_NOFILE)) {
-        /* test if it already exists to avoid loosing precious files */
+        /* test if it already exists to avoid losing precious files */
         if (!file_overwrite &&
             (strchr(filename, ':') == NULL ||
              filename[1] == ':' ||
diff --git a/libavcodec/arm/dsputil_init_neon.c 
b/libavcodec/arm/dsputil_init_neon.c
index acb2132..ffefe4a 100644
--- a/libavcodec/arm/dsputil_init_neon.c
+++ b/libavcodec/arm/dsputil_init_neon.c
@@ -1,5 +1,5 @@
 /*
- * ARM NEON optimised DSP functions
+ * ARM NEON-optimized DSP functions
  * Copyright (c) 2008 Mans Rullgard <[email protected]>
  *
  * This file is part of Libav.
diff --git a/libavcodec/arm/dsputil_neon.S b/libavcodec/arm/dsputil_neon.S
index 13f0699..7caacf5 100644
--- a/libavcodec/arm/dsputil_neon.S
+++ b/libavcodec/arm/dsputil_neon.S
@@ -1,5 +1,5 @@
 /*
- * ARM NEON optimised DSP functions
+ * ARM NEON-optimized DSP functions
  * Copyright (c) 2008 Mans Rullgard <[email protected]>
  *
  * This file is part of Libav.
diff --git a/libavcodec/arm/fft_neon.S b/libavcodec/arm/fft_neon.S
index b79a2dc..d9a4c6d 100644
--- a/libavcodec/arm/fft_neon.S
+++ b/libavcodec/arm/fft_neon.S
@@ -1,5 +1,5 @@
 /*
- * ARM NEON optimised FFT
+ * ARM NEON-optimized FFT
  *
  * Copyright (c) 2009 Mans Rullgard <[email protected]>
  * Copyright (c) 2009 Naotoshi Nojiri
diff --git a/libavcodec/arm/fmtconvert_neon.S b/libavcodec/arm/fmtconvert_neon.S
index 45cc84b..5abf257 100644
--- a/libavcodec/arm/fmtconvert_neon.S
+++ b/libavcodec/arm/fmtconvert_neon.S
@@ -1,5 +1,5 @@
 /*
- * ARM NEON optimised Format Conversion Utils
+ * ARM NEON-optimized format conversion utils
  * Copyright (c) 2008 Mans Rullgard <[email protected]>
  *
  * This file is part of Libav.
diff --git a/libavcodec/arm/int_neon.S b/libavcodec/arm/int_neon.S
index 5a14991..629ee9f 100644
--- a/libavcodec/arm/int_neon.S
+++ b/libavcodec/arm/int_neon.S
@@ -1,5 +1,5 @@
 /*
- * ARM NEON optimised integer operations
+ * ARM NEON-optimized integer operations
  * Copyright (c) 2009 Kostya Shishkov
  *
  * This file is part of Libav.
diff --git a/libavcodec/arm/mdct_neon.S b/libavcodec/arm/mdct_neon.S
index 1ba3067..4ef0445 100644
--- a/libavcodec/arm/mdct_neon.S
+++ b/libavcodec/arm/mdct_neon.S
@@ -1,5 +1,5 @@
 /*
- * ARM NEON optimised MDCT
+ * ARM NEON-optimized MDCT
  * Copyright (c) 2009 Mans Rullgard <[email protected]>
  *
  * This file is part of Libav.
diff --git a/libavcodec/arm/rdft_neon.S b/libavcodec/arm/rdft_neon.S
index fba275e..12c3887 100644
--- a/libavcodec/arm/rdft_neon.S
+++ b/libavcodec/arm/rdft_neon.S
@@ -1,5 +1,5 @@
 /*
- * ARM NEON optimised RDFT
+ * ARM NEON-optimized RDFT
  * Copyright (c) 2009 Mans Rullgard <[email protected]>
  *
  * This file is part of Libav.
diff --git a/libavcodec/arm/vp8dsp_neon.S b/libavcodec/arm/vp8dsp_neon.S
index 1b9f24e..76f6dce 100644
--- a/libavcodec/arm/vp8dsp_neon.S
+++ b/libavcodec/arm/vp8dsp_neon.S
@@ -1,5 +1,5 @@
 /**
- * VP8 NEON optimisations
+ * VP8 NEON optimizations
  *
  * Copyright (c) 2010 Rob Clark <[email protected]>
  * Copyright (c) 2011 Mans Rullgard <[email protected]>
diff --git a/libavcodec/avcodec.h b/libavcodec/avcodec.h
index 2e37f5a..1c9a129 100644
--- a/libavcodec/avcodec.h
+++ b/libavcodec/avcodec.h
@@ -3263,7 +3263,7 @@ typedef struct ReSampleContext ReSampleContext;
  * @param linear           if 1 then the used FIR filter will be linearly 
interpolated
                            between the 2 closest, if 0 the closest will be used
  * @param cutoff           cutoff frequency, 1.0 corresponds to half the 
output sampling rate
- * @return allocated ReSampleContext, NULL if error occured
+ * @return allocated ReSampleContext, NULL if error occurred
  */
 ReSampleContext *av_audio_resample_init(int output_channels, int 
input_channels,
                                         int output_rate, int input_rate,
diff --git a/libavcodec/bfi.c b/libavcodec/bfi.c
index 3c66226..6e18471 100644
--- a/libavcodec/bfi.c
+++ b/libavcodec/bfi.c
@@ -51,7 +51,7 @@ static int bfi_decode_frame(AVCodecContext * avctx, void 
*data,
     int buf_size = avpkt->size;
     BFIContext *bfi = avctx->priv_data;
     uint8_t *dst = bfi->dst;
-    uint8_t *src, *dst_offset, colour1, colour2;
+    uint8_t *src, *dst_offset, color1, color2;
     uint8_t *frame_end = bfi->dst + avctx->width * avctx->height;
     uint32_t *pal;
     int i, j, height = avctx->height;
@@ -148,11 +148,11 @@ static int bfi_decode_frame(AVCodecContext * avctx, void 
*data,
             break;
 
         case 3:                //Fill Chain
-            colour1 = bytestream_get_byte(&buf);
-            colour2 = bytestream_get_byte(&buf);
+            color1 = bytestream_get_byte(&buf);
+            color2 = bytestream_get_byte(&buf);
             while (length--) {
-                *dst++ = colour1;
-                *dst++ = colour2;
+                *dst++ = color1;
+                *dst++ = color2;
             }
             break;
 
diff --git a/libavcodec/bink.c b/libavcodec/bink.c
index 1768373..12446d0 100644
--- a/libavcodec/bink.c
+++ b/libavcodec/bink.c
@@ -41,7 +41,7 @@ static VLC bink_trees[16];
 enum OldSources {
     BINKB_SRC_BLOCK_TYPES = 0, ///< 8x8 block types
     BINKB_SRC_COLORS,          ///< pixel values used for different block types
-    BINKB_SRC_PATTERN,         ///< 8-bit values for 2-colour pattern fill
+    BINKB_SRC_PATTERN,         ///< 8-bit values for 2-color pattern fill
     BINKB_SRC_X_OFF,           ///< X components of motion value
     BINKB_SRC_Y_OFF,           ///< Y components of motion value
     BINKB_SRC_INTRA_DC,        ///< DC values for intrablocks with DCT
@@ -71,7 +71,7 @@ enum Sources {
     BINK_SRC_BLOCK_TYPES = 0, ///< 8x8 block types
     BINK_SRC_SUB_BLOCK_TYPES, ///< 16x16 block types (a subset of 8x8 block 
types)
     BINK_SRC_COLORS,          ///< pixel values used for different block types
-    BINK_SRC_PATTERN,         ///< 8-bit values for 2-colour pattern fill
+    BINK_SRC_PATTERN,         ///< 8-bit values for 2-color pattern fill
     BINK_SRC_X_OFF,           ///< X components of motion value
     BINK_SRC_Y_OFF,           ///< Y components of motion value
     BINK_SRC_INTRA_DC,        ///< DC values for intrablocks with DCT
@@ -117,8 +117,8 @@ typedef struct BinkContext {
     int            swap_planes;
 
     Bundle         bundle[BINKB_NB_SRC]; ///< bundles for decoding all data 
types
-    Tree           col_high[16];         ///< trees for decoding high nibble 
in "colours" data type
-    int            col_lastval;          ///< value of last decoded high 
nibble in "colours" data type
+    Tree           col_high[16];         ///< trees for decoding high nibble 
in "colors" data type
+    int            col_lastval;          ///< value of last decoded high 
nibble in "colors" data type
 } BinkContext;
 
 /**
@@ -128,12 +128,12 @@ enum BlockTypes {
     SKIP_BLOCK = 0, ///< skipped block
     SCALED_BLOCK,   ///< block has size 16x16
     MOTION_BLOCK,   ///< block is copied from previous frame with some offset
-    RUN_BLOCK,      ///< block is composed from runs of colours with custom 
scan order
+    RUN_BLOCK,      ///< block is composed from runs of colors with custom 
scan order
     RESIDUE_BLOCK,  ///< motion block with some difference added
     INTRA_BLOCK,    ///< intra DCT block
-    FILL_BLOCK,     ///< block is filled with single colour
+    FILL_BLOCK,     ///< block is filled with single color
     INTER_BLOCK,    ///< motion block with DCT applied to the difference
-    PATTERN_BLOCK,  ///< block is filled with two colours following custom 
pattern
+    PATTERN_BLOCK,  ///< block is filled with two colors following custom 
pattern
     RAW_BLOCK,      ///< uncoded 8x8 block
 };
 
diff --git a/libavcodec/bitstream.c b/libavcodec/bitstream.c
index 7071788..39e8782 100644
--- a/libavcodec/bitstream.c
+++ b/libavcodec/bitstream.c
@@ -103,7 +103,7 @@ static int alloc_table(VLC *vlc, int size, int use_static)
     vlc->table_size += size;
     if (vlc->table_size > vlc->table_allocated) {
         if(use_static)
-            abort(); //cant do anything, init_vlc() is used with too little 
memory
+            abort(); // cannot do anything, init_vlc() is used with too little 
memory
         vlc->table_allocated += (1 << vlc->bits);
         vlc->table = av_realloc(vlc->table,
                                 sizeof(VLC_TYPE) * 2 * vlc->table_allocated);
diff --git a/libavcodec/bmp.c b/libavcodec/bmp.c
index 21ebeec..a790632 100644
--- a/libavcodec/bmp.c
+++ b/libavcodec/bmp.c
@@ -175,7 +175,7 @@ static int bmp_decode_frame(AVCodecContext *avctx,
         if(hsize - ihsize - 14 > 0){
             avctx->pix_fmt = PIX_FMT_PAL8;
         }else{
-            av_log(avctx, AV_LOG_ERROR, "Unknown palette for 16-colour BMP\n");
+            av_log(avctx, AV_LOG_ERROR, "Unknown palette for 16-color BMP\n");
             return -1;
         }
         break;
diff --git a/libavcodec/cavs.c b/libavcodec/cavs.c
index 6f63c23..bb9b2bf 100644
--- a/libavcodec/cavs.c
+++ b/libavcodec/cavs.c
@@ -305,7 +305,7 @@ void ff_cavs_modify_mb_i(AVSContext *h, int *pred_mode_uv) {
     h->top_pred_Y[h->mbx*2+0] = h->pred_mode_Y[7];
     h->top_pred_Y[h->mbx*2+1] = h->pred_mode_Y[8];
 
-    /* modify pred modes according to availability of neighbour samples */
+    /* modify pred modes according to availability of neighbor samples */
     if(!(h->flags & A_AVAIL)) {
         modify_pred(ff_left_modifier_l, &h->pred_mode_Y[4] );
         modify_pred(ff_left_modifier_l, &h->pred_mode_Y[7] );
@@ -647,7 +647,7 @@ void ff_cavs_init_pic(AVSContext *h) {
  ****************************************************************************/
 
 /**
- * some predictions require data from the top-neighbouring macroblock.
+ * some predictions require data from the top-neighboring macroblock.
  * this data has to be stored for one complete row of macroblocks
  * and this storage space is allocated here
  */
diff --git a/libavcodec/cavs.h b/libavcodec/cavs.h
index eda76a8..6aba096 100644
--- a/libavcodec/cavs.h
+++ b/libavcodec/cavs.h
@@ -170,7 +170,7 @@ typedef struct {
     int alpha_offset, beta_offset;
     int ref_flag;
     int mbx, mby, mbidx; ///< macroblock coordinates
-    int flags;         ///< availability flags of neighbouring macroblocks
+    int flags;         ///< availability flags of neighboring macroblocks
     int stc;           ///< last start code
     uint8_t *cy, *cu, *cv; ///< current MB sample pointers
     int left_qp;
@@ -219,7 +219,7 @@ typedef struct {
     /* scaling factors for MV prediction */
     int sym_factor;    ///< for scaling in symmetrical B block
     int direct_den[2]; ///< for scaling in direct B block
-    int scale_den[2];  ///< for scaling neighbouring MVs
+    int scale_den[2];  ///< for scaling neighboring MVs
 
     int got_keyframe;
     DCTELEM *block;
diff --git a/libavcodec/cinepak.c b/libavcodec/cinepak.c
index 1d41ba2..1fb411b 100644
--- a/libavcodec/cinepak.c
+++ b/libavcodec/cinepak.c
@@ -104,10 +104,10 @@ static void cinepak_decode_codebook (cvid_codebook 
*codebook,
                 codebook[i].u  = 128 + *data++;
                 codebook[i].v  = 128 + *data++;
             } else {
-                /* this codebook type indicates either greyscale or
+                /* this codebook type indicates either grayscale or
                  * palettized video; if palettized, U & V components will
                  * not be used so it is safe to set them to 128 for the
-                 * benefit of greyscale rendering in YUV420P */
+                 * benefit of grayscale rendering in YUV420P */
                 codebook[i].y0 = *data++;
                 codebook[i].y1 = *data++;
                 codebook[i].y2 = *data++;
diff --git a/libavcodec/cook.c b/libavcodec/cook.c
index b5492db..05dcfbe 100644
--- a/libavcodec/cook.c
+++ b/libavcodec/cook.c
@@ -508,7 +508,7 @@ static inline void expand_category(COOKContext *q, int* 
category,
  *
  * @param q                     pointer to the COOKContext
  * @param index                 index
- * @param quant_index           quantisation index
+ * @param quant_index           quantization index
  * @param subband_coef_index    array of indexes to quant_centroid_tab
  * @param subband_coef_sign     signs of coefficients
  * @param mlt_p                 pointer into the mlt buffer
diff --git a/libavcodec/eatgv.c b/libavcodec/eatgv.c
index 917308f..7f8dffb 100644
--- a/libavcodec/eatgv.c
+++ b/libavcodec/eatgv.c
@@ -155,7 +155,7 @@ static int tgv_decode_inter(TgvContext * s, const uint8_t 
*buf, const uint8_t *b
     vector_bits       = AV_RL16(&buf[6]);
     buf += 12;
 
-    /* allocate codebook buffers as neccessary */
+    /* allocate codebook buffers as necessary */
     if (num_mvs > s->num_mvs) {
         s->mv_codebook = av_realloc(s->mv_codebook, num_mvs*2*sizeof(int));
         s->num_mvs = num_mvs;
@@ -286,7 +286,7 @@ static int tgv_decode_frame(AVCodecContext *avctx,
         s->frame.buffer_hints = FF_BUFFER_HINTS_VALID;
         s->frame.linesize[0] = s->width;
 
-        /* allocate additional 12 bytes to accomodate av_memcpy_backptr() 
OUTBUF_PADDED optimisation */
+        /* allocate additional 12 bytes to accommodate av_memcpy_backptr() 
OUTBUF_PADDED optimization */
         s->frame.data[0] = av_malloc(s->width*s->height + 12);
         if (!s->frame.data[0])
             return AVERROR(ENOMEM);
diff --git a/libavcodec/error_resilience.c b/libavcodec/error_resilience.c
index 11e2636..15d0b71 100644
--- a/libavcodec/error_resilience.c
+++ b/libavcodec/error_resilience.c
@@ -790,7 +790,7 @@ void ff_er_frame_end(MpegEncContext *s){
     if(!s->error_recognition || s->error_count==0 || s->avctx->lowres ||
        s->avctx->hwaccel ||
        s->avctx->codec->capabilities&CODEC_CAP_HWACCEL_VDPAU ||
-       s->picture_structure != PICT_FRAME || // we dont support ER of field 
pictures yet, though it should not crash if enabled
+       s->picture_structure != PICT_FRAME || // we do not support ER of field 
pictures yet, though it should not crash if enabled
        s->error_count==3*s->mb_width*(s->avctx->skip_top + 
s->avctx->skip_bottom)) return;
 
     if (s->current_picture.f.motion_val[0] == NULL) {
diff --git a/libavcodec/g722.c b/libavcodec/g722.c
index 74d5552..069792d 100644
--- a/libavcodec/g722.c
+++ b/libavcodec/g722.c
@@ -422,7 +422,7 @@ static int g722_encode_trellis(AVCodecContext *avctx,
 
         for (j = 0; j < frontier && nodes[0][j]; j++) {
             /* Only k >> 2 affects the future adaptive state, therefore testing
-             * small steps that don't change k >> 2 is useless, the orignal
+             * small steps that don't change k >> 2 is useless, the original
              * value from encode_low is better than them. Since we step k
              * in steps of 4, make sure range is a multiple of 4, so that
              * we don't miss the original value from encode_low. */
diff --git a/libavcodec/h264.c b/libavcodec/h264.c
index e5d0ed8..fe31e1b 100644
--- a/libavcodec/h264.c
+++ b/libavcodec/h264.c
@@ -2580,7 +2580,7 @@ static int decode_slice_header(H264Context *h, 
H264Context *h0){
 
         if(h->sps.video_signal_type_present_flag){
             s->avctx->color_range = h->sps.full_range ? AVCOL_RANGE_JPEG : 
AVCOL_RANGE_MPEG;
-            if(h->sps.colour_description_present_flag){
+            if (h->sps.color_description_present_flag) {
                 s->avctx->color_primaries = h->sps.color_primaries;
                 s->avctx->color_trc       = h->sps.color_trc;
                 s->avctx->colorspace      = h->sps.colorspace;
@@ -2709,7 +2709,7 @@ static int decode_slice_header(H264Context *h, 
H264Context *h0){
              * FIXME: avoiding a memcpy would be nice, but ref handling makes 
many assumptions
              * about there being no actual duplicates.
              * FIXME: this doesn't copy padding for out-of-frame motion 
vectors.  Given we're
-             * concealing a lost frame, this probably isn't noticable by 
comparison, but it should
+             * concealing a lost frame, this probably isn't noticeable by 
comparison, but it should
              * be fixed. */
             if (h->short_ref_count) {
                 if (prev) {
@@ -3130,7 +3130,7 @@ static av_always_inline void 
fill_filter_caches_inter(H264Context *h, MpegEncCon
 
 /**
  *
- * @return non zero if the loop filter can be skiped
+ * @return non zero if the loop filter can be skipped
  */
 static int fill_filter_caches(H264Context *h, int mb_type){
     MpegEncContext * const s = &h->s;
@@ -3648,7 +3648,7 @@ static int decode_nal_units(H264Context *h, const uint8_t 
*buf, int buf_size){
                 av_log(h->s.avctx, AV_LOG_ERROR, "Invalid mix of idr and 
non-idr slices");
                 return -1;
             }
-            idr(h); //FIXME ensure we don't loose some frames if there is 
reordering
+            idr(h); // FIXME ensure we don't lose some frames if there is 
reordering
         case NAL_SLICE:
             init_get_bits(&hx->s.gb, ptr, bit_length);
             hx->intra_gb_ptr=
diff --git a/libavcodec/h264.h b/libavcodec/h264.h
index 122a54a..e8027eb 100644
--- a/libavcodec/h264.h
+++ b/libavcodec/h264.h
@@ -184,7 +184,7 @@ typedef struct SPS{
     AVRational sar;
     int video_signal_type_present_flag;
     int full_range;
-    int colour_description_present_flag;
+    int color_description_present_flag;
     enum AVColorPrimaries color_primaries;
     enum AVColorTransferCharacteristic color_trc;
     enum AVColorSpace colorspace;
@@ -208,7 +208,7 @@ typedef struct SPS{
     int dpb_output_delay_length;       ///< dpb_output_delay_length_minus1 + 1
     int bit_depth_luma;                ///< bit_depth_luma_minus8 + 8
     int bit_depth_chroma;              ///< bit_depth_chroma_minus8 + 8
-    int residual_color_transform_flag; ///< residual_colour_transform_flag
+    int residual_color_transform_flag; ///< residual_color_transform_flag
     int constraint_set_flags;          ///< constraint_set[0-3]_flag
 }SPS;
 
diff --git a/libavcodec/h264_ps.c b/libavcodec/h264_ps.c
index 7491807..061443f 100644
--- a/libavcodec/h264_ps.c
+++ b/libavcodec/h264_ps.c
@@ -175,9 +175,9 @@ static inline int decode_vui_parameters(H264Context *h, SPS 
*sps){
         get_bits(&s->gb, 3);    /* video_format */
         sps->full_range = get_bits1(&s->gb); /* video_full_range_flag */
 
-        sps->colour_description_present_flag = get_bits1(&s->gb);
-        if(sps->colour_description_present_flag){
-            sps->color_primaries = get_bits(&s->gb, 8); /* colour_primaries */
+        sps->color_description_present_flag = get_bits1(&s->gb);
+        if (sps->color_description_present_flag) {
+            sps->color_primaries = get_bits(&s->gb, 8); /* color_primaries */
             sps->color_trc       = get_bits(&s->gb, 8); /* 
transfer_characteristics */
             sps->colorspace      = get_bits(&s->gb, 8); /* matrix_coefficients 
*/
             if (sps->color_primaries >= AVCOL_PRI_NB)
diff --git a/libavcodec/ivi_common.h b/libavcodec/ivi_common.h
index fd3d825..ebb9085 100644
--- a/libavcodec/ivi_common.h
+++ b/libavcodec/ivi_common.h
@@ -143,7 +143,7 @@ typedef struct {
     int             blk_size;       ///< block size
     int             is_halfpel;     ///< precision of the motion compensation: 
0 - fullpel, 1 - halfpel
     int             inherit_mv;     ///< tells if motion vector is inherited 
from reference macroblock
-    int             inherit_qdelta; ///< tells if quantiser delta is inherited 
from reference macroblock
+    int             inherit_qdelta; ///< tells if quantizer delta is inherited 
from reference macroblock
     int             qdelta_present; ///< tells if Qdelta signal is present in 
the bitstream (Indeo5 only)
     int             quant_mat;      ///< dequant matrix index
     int             glob_quant;     ///< quant base for this band
diff --git a/libavcodec/mpegvideo.h b/libavcodec/mpegvideo.h
index 923d46c..102700b 100644
--- a/libavcodec/mpegvideo.h
+++ b/libavcodec/mpegvideo.h
@@ -127,7 +127,7 @@ typedef struct Picture{
     int ref_poc[2][2][16];      ///< h264 POCs of the frames used as reference 
(FIXME need per slice)
     int ref_count[2][2];        ///< number of entries in ref_poc              
(FIXME need per slice)
     int mbaff;                  ///< h264 1 -> MBAFF frame 0-> not MBAFF
-    int field_picture;          ///< whether or not the picture was encoded in 
seperate fields
+    int field_picture;          ///< whether or not the picture was encoded in 
separate fields
 
     int mb_var_sum;             ///< sum of MB variance for current frame
     int mc_mb_var_sum;          ///< motion compensated MB variance for 
current frame
diff --git a/libavcodec/proresdec.c b/libavcodec/proresdec.c
index c70d145..351d4ac 100644
--- a/libavcodec/proresdec.c
+++ b/libavcodec/proresdec.c
@@ -589,7 +589,7 @@ static int decode_slice(ProresContext *ctx, int pic_num, 
int slice_num,
     sf = sf > 128 ? (sf - 96) << 2 : sf;
 
     /* scale quantization matrixes according with slice's scale factor */
-    /* TODO: this can be SIMD-optimized alot */
+    /* TODO: this can be SIMD-optimized a lot */
     if (ctx->qmat_changed || sf != ctx->prev_slice_sf) {
         ctx->prev_slice_sf = sf;
         for (i = 0; i < 64; i++) {
diff --git a/libavcodec/rv34.c b/libavcodec/rv34.c
index abdfce5..81c87bb 100644
--- a/libavcodec/rv34.c
+++ b/libavcodec/rv34.c
@@ -1050,7 +1050,7 @@ static void rv34_output_macroblock(RV34DecContext *r, 
int8_t *intra_types, int c
     int avail[6*8] = {0};
     int idx;
 
-    // Set neighbour information.
+    // Set neighbor information.
     if(r->avail_cache[1])
         avail[0] = 1;
     if(r->avail_cache[2])
@@ -1193,7 +1193,7 @@ static int rv34_decode_macroblock(RV34DecContext *r, 
int8_t *intra_types)
     int dist;
     int mb_pos = s->mb_x + s->mb_y * s->mb_stride;
 
-    // Calculate which neighbours are available. Maybe it's worth optimizing 
too.
+    // Calculate which neighbors are available. Maybe it's worth optimizing 
too.
     memset(r->avail_cache, 0, sizeof(r->avail_cache));
     fill_rectangle(r->avail_cache + 6, 2, 2, 4, 1, 4);
     dist = (s->mb_x - s->resync_mb_x) + (s->mb_y - s->resync_mb_y) * 
s->mb_width;
diff --git a/libavcodec/rv40.c b/libavcodec/rv40.c
index 7f6c8df..15e6830 100644
--- a/libavcodec/rv40.c
+++ b/libavcodec/rv40.c
@@ -433,8 +433,8 @@ enum RV40BlockPos{
 #define MASK_C_LEFT_COL   0x0005
 #define MASK_C_RIGHT_COL  0x000A
 
-static const int neighbour_offs_x[4] = { 0,  0, -1, 0 };
-static const int neighbour_offs_y[4] = { 0, -1,  0, 1 };
+static const int neighbor_offs_x[4] = { 0,  0, -1, 0 };
+static const int neighbor_offs_y[4] = { 0, -1,  0, 1 };
 
 /**
  * RV40 loop filtering function
@@ -447,7 +447,7 @@ static void rv40_loop_filter(RV34DecContext *r, int row)
     uint8_t *Y, *C;
     int alpha, beta, betaY, betaC;
     int q;
-    int mbtype[4];   ///< current macroblock and its neighbours types
+    int mbtype[4];   ///< current macroblock and its neighbors types
     /**
      * flags indicating that macroblock can be filtered with strong filter
      * it is set only for intra coded MB and MB with DCs coded separately
@@ -455,14 +455,14 @@ static void rv40_loop_filter(RV34DecContext *r, int row)
     int mb_strong[4];
     int clip[4];     ///< MB filter clipping value calculated from filtering 
strength
     /**
-     * coded block patterns for luma part of current macroblock and its 
neighbours
+     * coded block patterns for luma part of current macroblock and its 
neighbors
      * Format:
      * LSB corresponds to the top left block,
      * each nibble represents one row of subblocks.
      */
     int cbp[4];
     /**
-     * coded block patterns for chroma part of current macroblock and its 
neighbours
+     * coded block patterns for chroma part of current macroblock and its 
neighbors
      * Format is the same as for luma with two subblocks in a row.
      */
     int uvcbp[4][2];
@@ -502,7 +502,7 @@ static void rv40_loop_filter(RV34DecContext *r, int row)
         avail[3] = row < s->mb_height - 1;
         for(i = 0; i < 4; i++){
             if(avail[i]){
-                int pos = mb_pos + neighbour_offs_x[i] + 
neighbour_offs_y[i]*s->mb_stride;
+                int pos = mb_pos + neighbor_offs_x[i] + 
neighbor_offs_y[i]*s->mb_stride;
                 mvmasks[i] = r->deblock_coefs[pos];
                 mbtype [i] = s->current_picture_ptr->f.mb_type[pos];
                 cbp    [i] = r->cbp_luma[pos];
diff --git a/libavcodec/vaapi_h264.c b/libavcodec/vaapi_h264.c
index 51ebaaf..34fe766 100644
--- a/libavcodec/vaapi_h264.c
+++ b/libavcodec/vaapi_h264.c
@@ -247,7 +247,7 @@ static int start_frame(AVCodecContext          *avctx,
     pic_param->num_ref_frames                                   = 
h->sps.ref_frame_count;
     pic_param->seq_fields.value                                 = 0; /* reset 
all bits */
     pic_param->seq_fields.bits.chroma_format_idc                = 
h->sps.chroma_format_idc;
-    pic_param->seq_fields.bits.residual_colour_transform_flag   = 
h->sps.residual_color_transform_flag; /* XXX: only for 4:4:4 high profile? */
+    pic_param->seq_fields.bits.residual_color_transform_flag    = 
h->sps.residual_color_transform_flag; /* XXX: only for 4:4:4 high profile? */
     pic_param->seq_fields.bits.gaps_in_frame_num_value_allowed_flag = 
h->sps.gaps_in_frame_num_allowed_flag;
     pic_param->seq_fields.bits.frame_mbs_only_flag              = 
h->sps.frame_mbs_only_flag;
     pic_param->seq_fields.bits.mb_adaptive_frame_field_flag     = 
h->sps.mb_aff;
diff --git a/libavcodec/vaapi_mpeg4.c b/libavcodec/vaapi_mpeg4.c
index 1a756cb..5a1e849 100644
--- a/libavcodec/vaapi_mpeg4.c
+++ b/libavcodec/vaapi_mpeg4.c
@@ -98,7 +98,7 @@ static int vaapi_mpeg4_start_frame(AVCodecContext *avctx, 
av_unused const uint8_
         pic_param->forward_reference_picture  = 
ff_vaapi_get_surface_id(&s->last_picture);
 
     /* Fill in VAIQMatrixBufferMPEG4 */
-    /* Only the first inverse quantisation method uses the weighthing matrices 
*/
+    /* Only the first inverse quantization method uses the weighting matrices 
*/
     if (pic_param->vol_fields.bits.quant_type) {
         iq_matrix = ff_vaapi_alloc_iq_matrix(vactx, 
sizeof(VAIQMatrixBufferMPEG4));
         if (!iq_matrix)
diff --git a/libavcodec/wmaprodec.c b/libavcodec/wmaprodec.c
index 8fd2da5..11241f0 100644
--- a/libavcodec/wmaprodec.c
+++ b/libavcodec/wmaprodec.c
@@ -1419,7 +1419,7 @@ static int remaining_bits(WMAProDecodeCtx *s, 
GetBitContext *gb)
  *@param s codec context
  *@param gb bitstream reader context
  *@param len length of the partial frame
- *@param append decides wether to reset the buffer or not
+ *@param append decides whether to reset the buffer or not
  */
 static void save_bits(WMAProDecodeCtx *s, GetBitContext* gb, int len,
                       int append)
diff --git a/libavcodec/x86/rv40dsp.c b/libavcodec/x86/rv40dsp.c
index 9f90ad8..f20d531 100644
--- a/libavcodec/x86/rv40dsp.c
+++ b/libavcodec/x86/rv40dsp.c
@@ -1,5 +1,5 @@
 /*
- * RV40 decoder motion compensation functions x86-optimised
+ * RV40 decoder motion compensation functions x86-optimized
  * Copyright (c) 2008 Konstantin Shishkov
  *
  * This file is part of Libav.
@@ -21,7 +21,7 @@
 
 /**
  * @file
- * RV40 decoder motion compensation functions x86-optimised
+ * RV40 decoder motion compensation functions x86-optimized
  */
 
 #include "libavcodec/rv34dsp.h"
diff --git a/libavcodec/x86/vc1dsp_yasm.asm b/libavcodec/x86/vc1dsp_yasm.asm
index 220cc03..66f61db 100644
--- a/libavcodec/x86/vc1dsp_yasm.asm
+++ b/libavcodec/x86/vc1dsp_yasm.asm
@@ -227,7 +227,7 @@ section .text
     imul r2, 0x01010101
 %endmacro
 
-; I dont know why the sign extension is needed...
+; I do not know why the sign extension is needed...
 %macro PSIGNW_SRA_MMX 2
     psraw %2, 15
     PSIGNW_MMX %1, %2
diff --git a/libavdevice/jack_audio.c b/libavdevice/jack_audio.c
index c59a22d..53fedbf 100644
--- a/libavdevice/jack_audio.c
+++ b/libavdevice/jack_audio.c
@@ -270,7 +270,7 @@ static int audio_read_packet(AVFormatContext *context, 
AVPacket *pkt)
         }
     }
 
-    /* Wait for a packet comming back from process_callback(), if one isn't 
available yet */
+    /* Wait for a packet coming back from process_callback(), if one isn't 
available yet */
     timeout.tv_sec = av_gettime() / 1000000 + 2;
     if (sem_timedwait(&self->packet_count, &timeout)) {
         if (errno == ETIMEDOUT) {
diff --git a/libavdevice/oss_audio.c b/libavdevice/oss_audio.c
index c19c677..cd926d9 100644
--- a/libavdevice/oss_audio.c
+++ b/libavdevice/oss_audio.c
@@ -81,7 +81,7 @@ static int audio_open(AVFormatContext *s1, int is_output, 
const char *audio_devi
 
     s->frame_size = AUDIO_BLOCK_SIZE;
 
-    /* select format : favour native format */
+    /* select format : favor native format */
     err = ioctl(audio_fd, SNDCTL_DSP_GETFMTS, &tmp);
 
 #if HAVE_BIGENDIAN
diff --git a/libavdevice/v4l.c b/libavdevice/v4l.c
index 5c1caf8..79ec19c 100644
--- a/libavdevice/v4l.c
+++ b/libavdevice/v4l.c
@@ -154,7 +154,7 @@ static int grab_read_header(AVFormatContext *s1, 
AVFormatParameters *ap)
     ioctl(video_fd, VIDIOCSAUDIO, &audio);
 
     ioctl(video_fd, VIDIOCGPICT, &pict);
-    av_dlog(s1, "v4l: colour=%d hue=%d brightness=%d constrast=%d 
whiteness=%d\n",
+    av_dlog(s1, "v4l: color=%d hue=%d brightness=%d constrast=%d 
whiteness=%d\n",
             pict.colour, pict.hue, pict.brightness, pict.contrast, 
pict.whiteness);
     /* try to choose a suitable video format */
     pict.palette = desired_palette;
diff --git a/libavformat/avformat.h b/libavformat/avformat.h
index cc5457e..6868c76 100644
--- a/libavformat/avformat.h
+++ b/libavformat/avformat.h
@@ -610,7 +610,8 @@ typedef struct AVStream {
 
     /**
      * last packet in packet_buffer for this stream when muxing.
-     * used internally, NOT PART OF PUBLIC API, dont read or write from 
outside of libav*
+     * Used internally, NOT PART OF PUBLIC API, do not read or
+     * write from outside of libav*
      */
     struct AVPacketList *last_in_packet_buffer;
 
@@ -708,7 +709,7 @@ typedef struct AVFormatContext {
     /**
      * Decoding: duration of the stream, in AV_TIME_BASE fractional
      * seconds. Only set this value if you know none of the individual stream
-     * durations and also dont set any of them. This is deduced from the
+     * durations and also do not set any of them. This is deduced from the
      * AVStream values if not set.
      */
     int64_t duration;
diff --git a/libavformat/id3v2.c b/libavformat/id3v2.c
index c30ab4c..92a1957 100644
--- a/libavformat/id3v2.c
+++ b/libavformat/id3v2.c
@@ -81,7 +81,7 @@ static void free_geobtag(ID3v2ExtraMetaGEOB *geob)
  * @param maxread Pointer to maximum number of characters to read from the
  * AVIOContext. After execution the value is decremented by the number of bytes
  * actually read.
- * @returns 0 if no error occured, dst is uninitialized on error
+ * @returns 0 if no error occurred, dst is uninitialized on error
  */
 static int decode_str(AVFormatContext *s, AVIOContext *pb, int encoding,
                       uint8_t **dst, int *maxread)
diff --git a/libavformat/iv8.c b/libavformat/iv8.c
index bca31dc..5b90a30 100644
--- a/libavformat/iv8.c
+++ b/libavformat/iv8.c
@@ -23,7 +23,7 @@
 
 static int probe(AVProbeData *p)
 {
-    // the single file i have starts with that, i dont know if others do too
+    // the single file I have starts with that, i do not know if others do, too
     if(   p->buf[0] == 1
        && p->buf[1] == 1
        && p->buf[2] == 3
diff --git a/libavformat/mms.h b/libavformat/mms.h
index 36e772c..5235581 100644
--- a/libavformat/mms.h
+++ b/libavformat/mms.h
@@ -33,7 +33,7 @@ typedef struct {
 
     /** Buffer for outgoing packets. */
     /*@{*/
-    uint8_t *write_out_ptr;              ///< Pointer for writting the buffer.
+    uint8_t *write_out_ptr;              ///< Pointer for writing the buffer.
     uint8_t out_buffer[512];            ///< Buffer for outgoing packet.
     /*@}*/
 
diff --git a/libavformat/mxfenc.c b/libavformat/mxfenc.c
index d375e3f..d409e59 100644
--- a/libavformat/mxfenc.c
+++ b/libavformat/mxfenc.c
@@ -68,7 +68,7 @@ typedef struct {
     int index;               ///< index in mxf_essence_container_uls table
     const UID *codec_ul;
     int order;               ///< interleaving order if dts are equal
-    int interlaced;          ///< wether picture is interlaced
+    int interlaced;          ///< whether picture is interlaced
     int temporal_reordering;
     AVRational aspect_ratio; ///< display aspect ratio
     int closed_gop;          ///< gop is closed, used in mpeg-2 frame parsing
diff --git a/libavformat/timefilter.h b/libavformat/timefilter.h
index aa7db53..7ba5c10 100644
--- a/libavformat/timefilter.h
+++ b/libavformat/timefilter.h
@@ -72,7 +72,7 @@ TimeFilter * ff_timefilter_new(double clock_period, double 
feedback2_factor, dou
  *
  * system_time, in seconds, should be the value of the system clock time,
  * at (or as close as possible to) the moment the device hardware interrupt
- * occured (or any other event the device clock raises at the beginning of a
+ * occurred (or any other event the device clock raises at the beginning of a
  * cycle).
  *
  * @return the filtered time, in seconds
diff --git a/libavformat/utils.c b/libavformat/utils.c
index 0ba6fc3..f80b603 100644
--- a/libavformat/utils.c
+++ b/libavformat/utils.c
@@ -760,7 +760,7 @@ int av_read_packet(AVFormatContext *s, AVPacket *pkt)
             memset(pd->buf+pd->buf_size, 0, AVPROBE_PADDING_SIZE);
 
             if(av_log2(pd->buf_size) != av_log2(pd->buf_size - pkt->size)){
-                //FIXME we dont reduce score to 0 for the case of running out 
of buffer space in bytes
+                //FIXME we do not reduce score to 0 for the case of running 
out of buffer space in bytes
                 set_codec_from_probe_data(s, st, pd, st->probe_packets > 0 ? 
AVPROBE_SCORE_MAX/4 : 0);
                 if(st->codec->codec_id != CODEC_ID_PROBE){
                     pd->buf_size=0;
@@ -1073,7 +1073,7 @@ static void compute_pkt_fields(AVFormatContext *s, 
AVStream *st,
             FFSWAP(int64_t, st->pts_buffer[i], st->pts_buffer[i+1]);
         if(pkt->dts == AV_NOPTS_VALUE)
             pkt->dts= st->pts_buffer[0];
-        if(st->codec->codec_id == CODEC_ID_H264){ //we skiped it above so we 
try here
+        if(st->codec->codec_id == CODEC_ID_H264){ // we skipped it above so we 
try here
             update_initial_timestamps(s, pkt->stream_index, pkt->dts, 
pkt->pts); // this should happen on the first packet
         }
         if(pkt->dts > st->cur_dts)
diff --git a/libavutil/avr32/intreadwrite.h b/libavutil/avr32/intreadwrite.h
index e0049fe..89af896 100644
--- a/libavutil/avr32/intreadwrite.h
+++ b/libavutil/avr32/intreadwrite.h
@@ -36,7 +36,7 @@
  * the LDINS.B instruction, which gcc fails to utilise with the
  * generic code.  GCC also fails to use plain LD.W and ST.W even for
  * AP processors, so we override the generic code.  The 64-bit
- * versions are improved by using our optimised 32-bit functions.
+ * versions are improved by using our optimized 32-bit functions.
  */
 
 #define AV_RL16 AV_RL16
diff --git a/libavutil/eval.h b/libavutil/eval.h
index c485c69..ccb29e7 100644
--- a/libavutil/eval.h
+++ b/libavutil/eval.h
@@ -58,7 +58,7 @@ int av_expr_parse_and_eval(double *res, const char *s,
  * Parse an expression.
  *
  * @param expr a pointer where is put an AVExpr containing the parsed
- * value in case of successfull parsing, or NULL otherwise.
+ * value in case of successful parsing, or NULL otherwise.
  * The pointed to AVExpr must be freed with av_expr_free() by the user
  * when it is not needed anymore.
  * @param s expression as a zero terminated string, for example 
"1+2^3+5*5+sin(2/3)"
diff --git a/libpostproc/postprocess.c b/libpostproc/postprocess.c
index fb51d94..bb5ccaf 100644
--- a/libpostproc/postprocess.c
+++ b/libpostproc/postprocess.c
@@ -909,7 +909,7 @@ static void reallocBuffers(PPContext *c, int width, int 
height, int stride, int
             c->yHistogram[i]= width*height/64*15/256;
 
     for(i=0; i<3; i++){
-        //Note: The +17*1024 is just there so i do not have to worry about r/w 
over the end.
+        //Note: The +17*1024 is just there so I do not have to worry about r/w 
over the end.
         reallocAlign((void **)&c->tempBlurred[i], 8, stride*mbHeight*16 + 
17*1024);
         reallocAlign((void **)&c->tempBlurredPast[i], 8, 
256*((height+7)&(~7))/2 + 17*1024);//FIXME size
     }
diff --git a/libpostproc/postprocess_internal.h 
b/libpostproc/postprocess_internal.h
index 331a96b..d2c6708 100644
--- a/libpostproc/postprocess_internal.h
+++ b/libpostproc/postprocess_internal.h
@@ -100,7 +100,7 @@ typedef struct PPMode{
 
     int minAllowedY;                ///< for brigtness correction
     int maxAllowedY;                ///< for brihtness correction
-    float maxClippedThreshold;      ///< amount of "black" u r willing to 
loose to get a brightness corrected picture
+    float maxClippedThreshold;      ///< amount of "black" you are willing to 
lose to get a brightness-corrected picture
 
     int maxTmpNoise[3];             ///< for Temporal Noise Reducing filter 
(Maximal sum of abs differences)
 
diff --git a/tools/patcheck b/tools/patcheck
index 19faf47..f547446 100755
--- a/tools/patcheck
+++ b/tools/patcheck
@@ -66,7 +66,7 @@ $EGREP $OPT '^\+ *(const *|)static' $*| $EGREP --color=always 
'[^=]= *(0|NULL)[^
 cat $TMP
 hiegrep '# *ifdef * (HAVE|CONFIG)_' 'ifdefs that should be #if' $*
 
-hiegrep '\b(awnser|cant|dont|quantised|quantisation|teh|wont)\b' 'common 
typos' $*
+hiegrep 
'\b(awnser|cant|dont|wont|quantised|quantisation|optimised|optimisation|usefull|successfull|loose|occured|colour|favour|neighbour|grey|teh|alot|wether|skiped)\b'
 'common typos' $*
 
 hiegrep 'av_log\( *NULL' 'Missing context in av_log' $*
 hiegrep '[^sn]printf' 'Please use av_log' $*
diff --git a/libavformat/mov.c b/libavformat/mov.c
index 3190afd..4916c27 100644
--- a/libavformat/mov.c
+++ b/libavformat/mov.c
@@ -997,7 +997,7 @@ int ff_mov_read_stsd_entries(MOVContext *c, AVIOContext 
*pb, int entries)
 
         if(st->codec->codec_type==AVMEDIA_TYPE_VIDEO) {
             unsigned int color_depth, len;
-            int color_greyscale;
+            int color_grayscale;
 
             st->codec->codec_id = id;
             avio_rb16(pb); /* version */
@@ -1030,7 +1030,7 @@ int ff_mov_read_stsd_entries(MOVContext *c, AVIOContext 
*pb, int entries)
                    st->codec->bits_per_coded_sample, 
st->codec->color_table_id);
             /* figure out the palette situation */
             color_depth = st->codec->bits_per_coded_sample & 0x1F;
-            color_greyscale = st->codec->bits_per_coded_sample & 0x20;
+            color_grayscale = st->codec->bits_per_coded_sample & 0x20;
 
             /* if the depth is 2, 4, or 8 bpp, file is palettized */
             if ((color_depth == 2) || (color_depth == 4) ||
@@ -1039,9 +1039,9 @@ int ff_mov_read_stsd_entries(MOVContext *c, AVIOContext 
*pb, int entries)
                 unsigned int color_start, color_count, color_end;
                 unsigned char r, g, b;
 
-                if (color_greyscale) {
+                if (color_grayscale) {
                     int color_index, color_dec;
                     /* compute the greyscale palette */
                     st->codec->bits_per_coded_sample = color_depth;
                     color_count = 1 << color_depth;
                     color_index = 255;
@@ -1039,9 +1039,9 @@ int ff_mov_read_stsd_entries(MOVContext *c, AVIOContext 
                     int color_index, color_dec;
-                    /* compute the greyscale palette */
+                    /* compute the grayscale palette */
                     st->codec->bits_per_coded_sample = color_depth;
                     color_count = 1 << color_depth;
-- 
1.7.1

_______________________________________________
libav-devel mailing list
[email protected]
https://lists.libav.org/mailman/listinfo/libav-devel

Reply via email to